==> rheolef_6.5.orig.tar.gz: rheolef-6.5/nfem/ptst/field_indirect2_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
// check field_indirect with field rhs
#include "rheolef.h"
using namespace rheolef;
using namespace std;
size_t N;
Float f (const point& x) { return 1+(0.5/N)*(x[0]*(1-x[0])+x[1]*(1-x[1])+x[2]*(1-x[2])); }
Float g (const point& x) { 
  return -1-(x[0]+x[1]+x[2]);
}
int main(int argc, char**argv) {
  environment rheolef(argc, argv);
  geo omega (argv[1]);
  space Vh (omega, argv[2]);
  string dom_name = (argc > 3) ? argv[3] : "left";
  Float prec = (argc > 4) ? atof(argv[4]) : 1e-10;
  space Wh (omega[dom_name], argv[2]);
  N = omega.dimension();
  field fh = interpolate(Vh, f);
  field gh = interpolate(Wh, g);
  fh[dom_name] = gh;
  dout  << round (fh, prec);
}

==> rheolef_6.7.orig.tar.gz: rheolef-6.7/nfem/ptst/field_indirect2_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
// check field_indirect with field rhs
#include "rheolef.h"
using namespace rheolef;
using namespace std;
size_t N;
Float f (const point& x) { return 1+(0.5/N)*(x[0]*(1-x[0])+x[1]*(1-x[1])+x[2]*(1-x[2])); }
Float g (const point& x) { 
  return -1-(x[0]+x[1]+x[2]);
}
int main(int argc, char**argv) {
  environment rheolef(argc, argv);
  geo omega (argv[1]);
  space Vh (omega, argv[2]);
  string dom_name = (argc > 3) ? argv[3] : "left";
  Float prec = (argc > 4) ? atof(argv[4]) : 1e-10;
dis_warning_macro("main(1)");
  space Wh (omega[dom_name], argv[2]);
  N = omega.dimension();
  field fh = interpolate (Vh, f);
dis_warning_macro("main(2)");
  field gh = interpolate (Wh, g);
dis_warning_macro("main(2) gh=");
  derr << gh;
dis_warning_macro("main(3)");
  fh[dom_name] = gh;
dis_warning_macro("main(4)");
  dout  << round (fh, prec);
}
